@@ -5,7 +5,7 @@ use strict;
 use 5.008003;
 no warnings 'utf8';
 
-our $VERSION = '0.075';
+our $VERSION = '0.076';
 use Exporter 'import';
 our @EXPORT_OK = qw( print_table );
 
@@ -20,6 +20,19 @@ use Term::Choose::Util            qw( term_size insert_sep unicode_sprintf );
 use Term::TablePrint::ProgressBar qw();
 
 
+my $Plugin;
+BEGIN {
+    if ( $^O eq 'MSWin32' ) {
+        require Term::Choose::Win32;
+        $Plugin = 'Term::Choose::Win32';
+    }
+    else {
+        require Term::Choose::Linux;
+        $Plugin = 'Term::Choose::Linux';
+    }
+}
+
+
 sub new {
     my $class = shift;
     croak "new: called with " . @_ . " arguments - 0 or 1 arguments expected." if @_ > 1;
@@ -30,13 +43,14 @@ sub new {
         $self->__validate_options( $opt );
     }
     $self->{backup_opt} = { defined $opt ? %$opt : () };
+    $self->{plugin} = $Plugin->new();
     return $self;
 }
 
 
 sub DESTROY {
     my ( $self ) = @_;
-    print SHOW_CURSOR if $^O ne 'MSWin32';
+    $self->{plugin}->__show_cursor();
 }
 
 
@@ -100,7 +114,7 @@ sub __set_defaults {
 
 sub print_table {
     if ( ref $_[0] ne 'Term::TablePrint' ) {
-        return print_table( bless( {}, 'Term::TablePrint' ), @_ );
+        return print_table( bless( { plugin => $Plugin->new() }, 'Term::TablePrint' ), @_ );
     }
     my $self = shift;
     my ( $table_ref, $opt ) = @_;
@@ -127,7 +141,7 @@ sub print_table {
         $self->{idx_last_row} = $#$table_ref;
     }
     local $| = 1;
-    print HIDE_CURSOR if $^O ne 'MSWin32';
+    $self->{plugin}->__hide_cursor();
     my $col_idxs = [];
     if ( $self->{choose_columns}  ) {
         $col_idxs = $self->__choose_columns( $table_ref->[0] );
@@ -143,7 +157,7 @@ sub print_table {
     $self->{binray_regexp} = qr/[\x00-\x08\x0B-\x0C\x0E-\x1F]/;
     $self->{show_progress} = 0;
     if ( $self->{progress_bar} ) {
-        print CLEAR_SCREEN if $^O ne 'MSWin32';
+        $self->{plugin}->__clear_screen();
         print 'Computing:';
         $self->{show_progress} = int @$a_ref * @{$a_ref->[0]} / $self->{progress_bar};
     }
@@ -152,7 +166,7 @@ sub print_table {
     if ( exists $self->{backup_opt} ) {
         my $backup_opt = $self->{backup_opt};
         for my $key ( keys %$self ) {
-            if ( $key eq 'backup_opt' ) {
+            if ( $key eq 'plugin' || $key eq 'backup_opt' ) {
                 next;
             }
             elsif ( exists $backup_opt->{$key} ) {
@@ -163,7 +177,7 @@ sub print_table {
             }
         }
     }
-    print SHOW_CURSOR if $^O ne 'MSWin32';
+    $self->{plugin}->__show_cursor();
 }
 
 
@@ -605,7 +619,7 @@ Term::TablePrint - Print a table to the terminal and browse it interactively.
 
 =head1 VERSION
 
-Version 0.075
+Version 0.076
 
 =cut
 
